# -*- coding: utf-8 -*-
from spyne import ComplexModel, Boolean, Date, Integer, Unicode, srpc
from spyne.model.fault import Fault

from m3_example_app.person.models import Person
from m3_example_app.unit.models import Unit


class PersonData(ComplexModel):
    surname = Unicode(sub_name="Surname", max_occurs=1)
    firstname = Unicode(sub_name="Firstname", max_occurs=1)
    patronymic = Unicode(sub_name="Patronymic", max_occurs=1)
    date_of_birth = Date(sub_name="DateOfBirth", max_occurs=1)
    unit_id = Integer(sub_name="UnitID", max_occurs=1)

    class Annotations(ComplexModel.Annotations):
        doc = u'Данные физического лица.'


class PersonInfo(ComplexModel):
    person = PersonData.customize(sub_name="PersonData", max_occurs=1)

    class Annotations(ComplexModel.Annotations):
        doc = u'Контейнер данных физического лица.'


@srpc(PersonInfo.customize(nillable=False, min_occurs=1, max_occurs=1,
                           sub_name='PersonInfo'),
      _returns=Boolean)
def AddPerson(person):
    # Глобальный обработчик исключений использован для соответствия ТЗ
    try:
        person_data = person[0]
        if None in (
                person_data.surname, person_data.firstname,
                person_data.patronymic):
            raise Fault(
                faultcode=u"Client",
                faultstring=u"Недостаточно переданных аргументов",
            )

        if person_data.unit_id:
            try:
                unit = Unit.objects.get(id=person_data.unit_id)
            except Unit.DoesNotExist:
                raise Fault(
                    faultcode=u"Client",
                    faultstring=u"Указанное учреждение не найдено"
                )
        else:
            unit = None

        if len(person_data.surname) > Person._meta.get_field(
                'surname').max_length:
            raise Fault(
                faultcode=u"Client",
                faultstring=u'Поле Фамилия больше разрешенной '
                            u'длины ({0} символов)'.format(
                    Person._meta.get_field('surname').max_length),
                detail=u"Текущий размер: {0}".format(len(person_data.surname)),
            )

        if len(person_data.firstname) > Person._meta.get_field(
                'firstname').max_length:
            raise Fault(
                faultcode=u"Client",
                faultstring=u'Поле Имя больше разрешенной '
                            u'длины ({0} символов)'.format(
                    Person._meta.get_field('firstname').max_length),
                detail=u"Текущий размер: {0}".format(
                    len(person_data.firstname)),
            )

        if len(person_data.patronymic) > Person._meta.get_field(
                'patronymic').max_length:
            raise Fault(
                faultcode=u"Client",
                faultstring=u'Поле Фамилия больше разрешенной '
                            u'длины ({0} символов)'.format(
                    Person._meta.get_field('patronymic').max_length),
                detail=u"Текущий размер: {0}".format(
                    len(person_data.patronymic)),
            )

        new_person = Person(
            surname=person_data.surname,
            firstname=person_data.firstname,
            patronymic=person_data.patronymic,
            date_of_birth=person_data.date_of_birth,
            unit=unit,
        )
        try:
            new_person.save()
        except Exception as e:
            raise Fault(
                faultcode=u"Server",
                faultstring=u"Во время сохранения произошла ошибка",
                detail=e.message,
            )
    except Exception:
        return False
    else:
        return True
