# -*- coding: utf-8 -*-
import os
import yaml

from educommon.auth.simple_auth import get_login_url

DEBUG = True
TEMPLATE_DEBUG = DEBUG

PROJECT_PATH = os.path.abspath(os.path.dirname(__file__))
ADMINS = ()

MANAGERS = ADMINS

CONFIG_FILE = "config.yaml"

with open(CONFIG_FILE, 'r') as ymlfile:
    cfg = yaml.load(ymlfile)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': cfg['database']['name'],
        'USER': cfg['database']['user'],
        'PASSWORD': cfg['database']['password'],
        'HOST': cfg['database']['host'],
        'PORT': cfg['database']['port'],
    }
}

TIME_ZONE = 'Europe/Moscow'

LANGUAGE_CODE = 'ru-RU'

DATE_FORMAT = '%d.%m.%Y'

SITE_ID = 1

USE_I18N = True

USE_L10N = True

MEDIA_ROOT = os.path.join(PROJECT_PATH, 'media')
MEDIA_URL = 'media'
STATIC_ROOT = os.path.join(PROJECT_PATH, 'static')
STATIC_URL = '/static/'
STATICFILES_DIRS = ()
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

SECRET_KEY = '0i1ha9wvq8!_g!^&qfdrel@-rcz3dsa#up7*x54gsezgpv5ppsxqa'

if not DEBUG:
    TEMPLATE_LOADERS = (
        (
            'django.template.loaders.cached.Loader', (
                'django.template.loaders.filesystem.Loader',
                'django.template.loaders.app_directories.Loader',
                'm3_ext.ui.js_template_loader.load_template_source',
            )
        ),
    )
else:
    TEMPLATE_LOADERS = (
        'django.template.loaders.filesystem.Loader',
        'django.template.loaders.app_directories.Loader',
        'm3_ext.ui.js_template_loader.load_template_source',
    )

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'm3.PrettyTracebackMiddleware',
)

ROOT_URLCONF = 'urls'

TEMPLATE_DIRS = ()

TEMPLATE_CONTEXT_PROCESSORS = (
    "django.contrib.auth.context_processors.auth",
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "django.core.context_processors.static",
)

INSTALLED_APPS = (
    'm3_example_app.core',
    'm3_example_app.auth',
    'm3_example_app.unit',
    'm3_example_app.person',
    'wsfactory',
    'educommon.auth.simple_auth',
    'm3',
    'm3_ext',
    'objectpack',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
)

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}

CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
    }
}

LOGIN_URL = get_login_url()

WSFACTORY_CONFIG_FILE = "wsfactory_config.xml"

