# -*- coding: utf-8 -*-
from objectpack.tree_object_pack.actions import TreeObjectPack
from objectpack.tree_object_pack.ui import BaseTreeListWindow
from objectpack.ui import ModelEditWindow

from m3_example_app.controllers import core_observer
from .models import Unit
from .ui import UnitAddWindow


class UnitActionPack(TreeObjectPack):
    url = r'/unit'

    model = Unit

    load_trees_on_search = True

    add_window = UnitAddWindow.fabricate(
        Unit,
        model_register=core_observer,
        field_list=['name', 'inn', 'kpp', 'parent_id', 'unit_type']
    )

    edit_window = ModelEditWindow.fabricate(
        Unit,
        model_register=core_observer,
        field_list=['name', 'inn', 'kpp', 'parent_id', 'unit_type']
    )

    list_window = BaseTreeListWindow
    can_delete = True
    add_to_desktop = True

    columns = [
        {
            'data_index': 'name',
            'header': u'Навание',
            'searchable': True,
            'sortable': True,
        },
        {
            'data_index': 'inn',
            'header': u'ИНН',
            'searchable': True,
            'sortable': False,
        },
        {
            'data_index': 'kpp',
            'header': u'КПП',
            'searchable': True,
            'sortable': False,
        }
    ]

    list_sort_order = ('name',)

    def extend_menu(self, menu):
        return (
            menu.registries(
                menu.Item(self.title, self),
            )
        )

    def get_edit_window_params(self, params, request, context):
        params = super(UnitActionPack, self).get_edit_window_params(
            params, request, context
        )
        # Сохраняем значение parent_id для новых учреждений
        if params['create_new'] and context.parent_id:
            params['parent'] = Unit.objects.get(pk=context.parent_id)
        return params
