# -*- coding: utf-8 -*-
from django.db import models
from mptt.models import MPTTModel, TreeForeignKey


class Unit(MPTTModel):
    u"""
    Модель министерств и учреждений.
    """
    name = models.CharField(
        verbose_name=u'Название',
        max_length=255,
        unique=True,
    )

    inn = models.CharField(
        verbose_name=u'ИНН',
        max_length=12,
        unique=True,
    )

    kpp = models.CharField(
        verbose_name=u'КПП',
        max_length=9,
        unique=True,
    )

    parent = TreeForeignKey(
        'self',
        verbose_name=u'Министерство',
        null=True,
        blank=True,
        related_name='children',
        db_index=True,
    )

    MINISTRY = 1
    INSTITUTION = 2

    UNIT_TYPE_CHOICES = (
        (MINISTRY, u'Министерство'),
        (INSTITUTION, u'Учреждение'),
    )

    unit_type = models.SmallIntegerField(
        verbose_name=u'Тип',
        choices=UNIT_TYPE_CHOICES,
    )

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = u'Учреждение'
        verbose_name_plural = u'Учреждения'
